# API Reference

## Classes

```{eval-rst}
.. currentmodule:: tof

.. autosummary::
   :toctree: ../generated/classes
   :template: class-template.rst
   :recursive:

   Chopper
   ChopperReading
   ComponentReading
   Dashboard
   Detector
   DetectorReading
   Model
   ReadingField
   Result
   Source
   SourceParameters
```

## Top-level functions

```{eval-rst}
.. autosummary::
   :toctree: ../generated/functions
   :recursive:
```

## Submodules

```{eval-rst}
.. autosummary::
   :toctree: ../generated/modules
   :template: module-template.rst
   :recursive:

   utils
```
